@@ -5,7 +5,7 @@ Contains the go to assignments mode.
 import logging
 import os
 from pyqode.core import icons
-from pyqode.qt import QtCore, QtGui, QtWidgets
+from qtpy import QtCore, QtGui, QtWidgets
 from pyqode.core.api import Mode, TextHelper, DelayJobRunner, CodeEdit
 from pyqode.core.backend import NotRunning
 from pyqode.core.modes import WordClickMode
@@ -66,7 +66,7 @@ class GoToAssignmentsMode(WordClickMode):
         super(GoToAssignmentsMode, self).__init__()
         self._definitions = []
         self._goto_requested = False
-        self.action_goto = QtWidgets.QAction("Go to assignments", self)
+        self.action_goto = QtWidgets.QAction(_("Go to assignments"), self)
         self.action_goto.setShortcut(self.shortcut)
         self.action_goto.triggered.connect(self.request_goto)
         icon = icons.icon(qta_name='fa.share')
@@ -78,9 +78,9 @@ class GoToAssignmentsMode(WordClickMode):
     def on_state_changed(self, state):
         super(GoToAssignmentsMode, self).on_state_changed(state)
         if state:
-            self.editor.add_action(self.action_goto)
+            self.editor.add_action(self.action_goto, sub_menu='Python')
         else:
-            self.editor.remove_action(self.action_goto)
+            self.editor.remove_action(self.action_goto, sub_menu='Python')
 
     def request_goto(self):
         """
@@ -184,8 +184,8 @@ class GoToAssignmentsMode(WordClickMode):
                 "More than 1 assignments in different modules, user "
                 "need to make a choice: %s" % definitions)
             def_str, result = QtWidgets.QInputDialog.getItem(
-                self.editor, "Choose a definition",
-                "Choose the definition you want to go to:",
+                self.editor, _("Choose a definition"),
+                _("Choose the definition you want to go to:"),
                 [str(d) for d in definitions])
             if result:
                 for definition in definitions:
@@ -194,4 +194,4 @@ class GoToAssignmentsMode(WordClickMode):
                         break
 
     def _on_word_clicked(self):
-        self._perform_goto(self._definitions)
+        self._perform_goto(self._definitions)
\ No newline at end of file
